'use strict';

var prettier = require('prettier');

/**
 * 将代码插入到指定的位置中
 * @param  {string} sourceCode 被插入代码的源码
 * @param  {Array<CodeSnap>} codeSnaps 代码片段，格式： { code: 'import xxx from'xxx';', slotName: 'import' }。会将sourcecode里对应slot的地方插入代码
 * @returns 转换后的代码 Promise<string>
 */
function insertCode(sourceCode, codeSnaps) {
    return new Promise(function (resolve, reject) {
        prettier.resolveConfig(process.cwd()).then(function (prettierConfig) {
            // @ts-ignore
            var _a = prettier.__debug.parse(sourceCode, prettierConfig), ast = _a.ast, text = _a.text;
            sourceCode = text;
            var codeArray = [];
            var currentIndex = 0;
            if (ast !== null && ast.type === "File") {
                var file = ast;
                if (file.comments && file.comments.length > 0) {
                    // 首先检查有没有注释
                    ast.comments.forEach(function (comment) {
                        var matchResult = comment.value.match(/.*?code-insert.*?( slot=[\"\'](.*?)[\"\'])/);
                        // 看看有没有 @code-insert 的注释
                        if (matchResult && matchResult.length > 0) {
                            var slotName_1 = matchResult[2];
                            codeSnaps.forEach(function (codeSnap) {
                                if (codeSnap.slotName === slotName_1) {
                                    // 根据解析到的slotName找到对应的代码插入
                                    codeArray.push(sourceCode.substring(currentIndex, comment.end));
                                    codeArray.push("\r\n" + codeSnap.code);
                                    currentIndex = comment.end;
                                }
                            });
                        }
                    });
                }
                codeArray.push(sourceCode.substr(currentIndex));
            }
            // @ts-ignore
            resolve(prettier.format(codeArray.join(""), prettierConfig));
        });
    });
}

module.exports = insertCode;
